@@ -24,19 +24,22 @@ class AnalyticsClientAsync(AnalyticsClient):
 
         _create_async_methods_in(self, client)
 
-    @asyncio.coroutine  # type: ignore
+    @asyncio.coroutine
     def __aenter__(self):
-        # type: () -> AnalyticsClientAsync
+        # type: () -> AnalyticsClientAsync # type: ignore
 
         return self  # type: ignore
 
-    @asyncio.coroutine  # type: ignore
-    def __aexit__(self, exc_type, exc, tb):
+    @asyncio.coroutine
+    def __aexit__(self, exc_type, exc, tb):  # type: ignore
         # type: (Optional[Type[BaseException]], Optional[BaseException],Optional[types.TracebackType]) -> None # noqa: E501
 
-        yield from self.close()
+        yield from self.close_async()  # type: ignore
 
-    def close(self):
-        # type: () -> types.GeneratorType
+    @asyncio.coroutine
+    def close_async(self):  # type: ignore
+        # type: () -> None
 
-        return self._transporter_async._requester.close()  # type: ignore
+        super().close()
+
+        yield from self._transporter_async.close()  # type: ignore
