@@ -115,8 +115,13 @@ class SearchIndex(object):
         if safe:
             responses.wait()
 
-        tmp_index = copy.copy(self)
-        tmp_index._name = tmp_index_name
+        try:
+            from algoliasearch.search_client import SearchClient
+        except ImportError:  # Already imported.
+            pass
+
+        tmp_client = SearchClient(self._transporter, self._config)
+        tmp_index = tmp_client.init_index(tmp_index_name)
 
         responses.push(tmp_index.save_objects(objects, request_options))
 
